@@ -857,3 +857,58 @@ class DataPlate:
         except Exception as e:
             logging.exception('download_notebook_result , ' + str(e))
             raise Error(e)
+
+
+
+
+    def list_datasets(self, mine = True):
+        """Returns a list of datasets defined in the system
+        Args:
+        mine (boolean): return only datasets that I'm allowed to query (default: True)
+        """
+
+        try:
+
+            params = {}
+            if mine:
+                params['mine'] = mine
+
+            headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
+
+            try:
+                logging.info('sending request...')
+                r = self.session.post( \
+                    '{}/api/list_datasets'.format(self.base_url), params=params, data="",
+                    headers=headers, stream=True, allow_redirects=False)
+
+                if r.status_code != 200:
+                    if r.status_code == 302:
+                        raise Error(
+                            'Bad Access Key! Get your access key at: {}'.format(
+                                self.base_url))
+                    if r.status_code == 206:
+                        logging.info('still working...')
+                        time.sleep(5)
+                    raise Error(
+                        'Bad HTTP exit status returned from the API: {}. Error was: {}'.
+                            format(r.status_code, r.text))
+
+                logging.info('Parsing response')
+                # logging.info(str(r.text))
+                if r.text:
+                    rJson = json.loads(r.text)
+                    logging.info('list datasets finished')
+                    df = pd.read_json(json.dumps(rJson))
+                    return df
+                else:
+                    logging.exception('Could not find proper output, please check your parameters')
+                # return r.text
+
+            except (requests.exceptions.ConnectionError,
+                    requests.exceptions.ReadTimeout) as e:
+                logging.exception('Got ConnectionError/ReadTimeout exception.')
+                raise Error(e)
+
+        except Exception as e:
+            logging.exception('list_datasets , ' + str(e))
+            raise Error(e)
\ No newline at end of file
